import { CSSProperties, FC } from "react"
import { Text, ITouchEvent } from "@tarojs/components"
import './icon.css'

export type IconName =
  | 'arrow-clockwise'
  | 'arrow-counterclockwise'
  | 'backspace'
  | 'bar-chart'
  | 'bar-chart-line'
  | 'caret-down'
  | 'caret-up'
  | 'caret-left'
  | 'caret-right'
  | 'check'
  | 'check-all'
  | 'chevron-double-down'
  | 'chevron-double-up'
  | 'chevron-double-left'
  | 'chevron-double-right'
  | 'chevron-down'
  | 'chevron-up'
  | 'chevron-left'
  | 'chevron-right'
  | 'circle'
  | 'exclamation'
  | 'gear'
  | 'gender-female'
  | 'gender-male'
  | 'heart'
  | 'info'
  | 'list'
  | 'lock'
  | 'unlock'
  | 'play-btn'
  | 'play'
  | 'question'
  | 'shield'
  | 'square'
  | 'star'
  | 'three-dots-vertical'
  | 'three-dots'
  | 'trash'
  | 'x'

export type IconShape =
  | 'circle'
  | 'square'
  | 'diamond'
  | 'octagon'
  | 'triangle'

export interface IconProps {
  name: IconName
  shape?: IconShape
  color?: string
  size?: string | number
  fill?: boolean
  className?: string
  style?: CSSProperties
  onClick?: (event: ITouchEvent) => void
}

const XgIcon: FC<IconProps> = (props) => {
  const name = [
    props.name,
    props.shape,
    props.fill ? 'fill' : undefined
  ].filter(Boolean).join('-')

  const color = props.color ?? 'currentColor'
  const size = typeof props.size === 'string' ? props.size : `${props.size ?? 16}px`
  const fontStyle: CSSProperties = {
    ...(props.style ?? {}),
    fontSize: size,
    color,
  }

  return (
    <Text
      className={`xg-icon xg-icon-${name} ${props.className}`}
      style={fontStyle}
      onClick={props.onClick}
    />
  )
}

export default XgIcon
