import {FC} from "react";
import {Button, Image, View} from "@tarojs/components";
import emptyImg from '@/static/img/empty.png'
import styles from './empty.module.scss'
import MyButton from "@/components/button/MyButton";
import Taro from "@tarojs/taro";

interface Props {
  name: string
  showBack?: boolean
  onRefresh?:() => void
}

const Empty: FC<Props> = ({name, showBack, onRefresh}) => {
  const hasBack = showBack && Taro.getCurrentPages().length > 1
  const hasRefresh = onRefresh != null
  return (
    <View className={styles.empty}>
      <Image src={emptyImg} mode='widthFix' className={styles.image} fadeIn lazyLoad/>
      <View className={styles.name}>{name}</View>
      {(hasBack || hasRefresh) && (
        <View  className='flex justify-center align-center gap60rpx mt-3'>
          {hasBack && <Button type={'default'} size={'mini'} style={{padding:'0 20px'}} onClick={() => Taro.navigateBack()}>返回</Button>}
          {hasRefresh && <MyButton size={'mini'} style={{padding:'0 20px'}} onClick={onRefresh} type="primary">刷新</MyButton>}
        </View>
      )}
    </View>
  )
}

export default Empty
