import Taro from "@tarojs/taro";

type Topic = string | symbol
type Subscriber = (...args: any[]) => void

export default function usePubsub() {
  const events = new Map<Topic, Subscriber[]>()
  const registers = new Map<Topic, Subscriber>()

  const pub = (topic: Topic, data: any) => {
    Taro.eventCenter.trigger(topic, data)
  };

  const sub = (topic: Topic, callback: Subscriber) => {
    const cbs = events.get(topic) ?? []
    events.set(topic, cbs.concat(callback))
    if (!registers.has(topic)) {
      console.log({topic})
      const listener = (...args: any[]): void => {
        events.get(topic)?.forEach((cb) => cb(...args))
      }
      registers.set(topic, listener)
      Taro.eventCenter.on(topic, listener)
    }
  };

  Taro.useUnload(() => {
    registers.forEach((listener, topic) => {
      Taro.eventCenter.off(topic, listener)
    })
    registers.clear()
    events.clear()
  })

  return {
    pub,
    sub
  }
}
