import {FC, useCallback, useEffect, useRef, useState} from "react";
import {Form, Image, Input, Text, View} from "@tarojs/components";
import {Profile} from "@/store";
import {userApi} from "@/api";
import Taro from "@tarojs/taro";
import {regexTel} from "@/utils/regu";
import styles from './check.module.scss'
import code from '@/static/img/vCode.png'
import tel from '@/static/img/tel.png'
import MyButton from "@/components/button/MyButton";
import IconFont from "@/components/IconFont";

const Bing: FC = () => {
  const form = useRef<HTMLFormElement | null>(null)
  const [loading, setLoading] = useState(false)
  const [codeTime, setCodeTime] = useState(0)
  const {setUser, setToken, setCompany} = Profile.useContainer()
  const [openid, setOpenId] = useState('')
  const [phone_number, setPhone_number] = useState<number | null>()

  useEffect(() => {
    if (codeTime > 0) {
      setTimeout(() => {
        setCodeTime(codeTime - 1)
      }, 1000)
    }
  }, [codeTime])

  Taro.useLoad(() => {
    if (process.env.TARO_ENV === 'h5') {
      setOpenId(localStorage.getItem('openid') || '')
    } else {
      setOpenId(Taro.getStorageSync('openid'))
    }
  })

  async function Submit(data) {
    setLoading(true)
    const value = data.target.value
    if (!regexTel.exec(value.phone_number)) {
      Taro.showToast({title: '手机号错误', icon: 'error'})
      setLoading(false)
      return
    }
    try {
      const res = await userApi.checkout({
        ...value,
        openid,
      })
      if (res) {
        setCompany(res.company)
        setUser(res.user)
        setToken(res.token)
        Taro.switchTab({url: '/pages/home/home'})
      }
    } catch (e) {
    }
    setLoading(false)
  }

  const getCode = useCallback(async () => {
    if (codeTime > 0) return;
    if (!phone_number || !regexTel.exec(String(phone_number))) {
      Taro.showToast({title: '手机号错误', icon: 'error'})
      setLoading(false)
      return
    }

    try {
      await userApi.getCode(phone_number)
      Taro.showToast({title: '请注意查收', icon: "none"})
      setCodeTime(60)
    } catch (e) {
      Taro.showToast({title: '获取短信验证码失败', icon: "error"})
    }
  }, [codeTime, phone_number])

  return (
    <View className={styles.page}>

      <View className="p-3 mb-7 flex align-baseline font-30 lh1_5" style={{color:'#FF9E5F',backgroundColor:'#fff5ef'}}>
        <IconFont className="mr-2" name={'exclamation'} shape={'triangle'} fill></IconFont>
        <View className="flex-1">
          <Text>检测到您第一次登录，需要通过手机号码验证是否为</Text>
          <Text className="bold">我司战略合作的客户员工</Text>
          <Text>，如果无法完成验证请点击</Text>
          <Text onClick={()=>{
            Taro.navigateTo({
              url:`/pages/preview/webView/webView?url=${encodeURIComponent(`${process.env.TARO_APP_API}/QA/yuangongyanzheng.html`)}`
            })
          }} className="text-success mx-1" style={{textDecoration:'underline'}}>相关问题解答</Text>
          <Text>!</Text>
        </View>

      </View>

      <Form onSubmit={Submit} ref={form}>

        <View className={styles.formItem}>
          <View>
            <Image src={tel} className={styles.image}/>
          </View>
          <Input
            type='number'
            name='phone_number'
            placeholder={'手机号码'}
            value={phone_number as unknown as string}
            onInput={(e) => setPhone_number(Number(e.detail.value))}/>
        </View>

        <View className={styles.formItem}>
          <View>
            <Image src={code} className={styles.image}/>
          </View>

          <View className='flex align-center flex-1'>
            <Input type='number' name='code' className='flex-1' placeholder='短信验证码'/>
            <View onClick={getCode}>
              {codeTime > 0 ? `${codeTime}` : '获取验证码'}
            </View>
          </View>
        </View>


        <MyButton
          className={styles.submit}
          formType='submit'
          disabled={loading}
        >
          提交
        </MyButton>
      </Form>
    </View>
  )
}


export default Bing;
