import {FC, useEffect, useState} from "react";
import {View, Text} from "@tarojs/components";
import styles from './index.module.scss'
import {VideoList} from "@/pages/index/components/videoList";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import {CoursesKey, publicApi} from "@/api/public";
import NavigationBar from "@/components/navigationBar/navigationBar";
import Spin from "@/components/spinner";
import {isBoolean} from "@tarojs/shared";
import ArticlesBox from "@/components/articlesBox/articlesBox";
import PageScript from "@/components/pageScript/pageScript";
import Taro from "@tarojs/taro";

const category: TabList[] = [
  {title: "企选课程", value: 'is_required'},
  {title: "平台课程", value: 'is_not_required'},
]

const Index: FC = () => {
  const [categoryKey, setCategoryKey] = useState<CoursesKey>('is_required')

  function tabChange(data: OnChangOpt) {
    setCategoryKey(data.tab?.value as CoursesKey)
  }

  Taro.useShareAppMessage((res) => {
    if(res.from === 'button'){

    }
    return {
      title:'信桂',
      path: '/pages/index/index'
    }
  })

  Taro.useShareTimeline(() => {
    return {
      title: '信桂'
    }
  })

  return (
    <View className={styles.content}>
      <NavigationBar
        cancelBack
        leftNode={<Tabs tabList={category} onChange={tabChange} current={categoryKey} scrollable={false} hiddenSliding/>}
      />
      <VideoList
        categoryKey={categoryKey}
        setCategoryKey={(categoryKey) => setCategoryKey(categoryKey)}
      />
    </View>
  )
}

const AuditMode: FC = () => {
  const [auditMode, setAuditMode] = useState(true)
  const [articles, setArticles] = useState<any[]>([])
  const [enable, setEnable] = useState(true)
  useEffect(() => {
    publicApi.course({page: 1, pageSize: 10}).then(res => {
      setAuditMode(isBoolean(res.audit_mode) ? res.audit_mode : res.audit_mode === 'true')
      setArticles(res.articles)
      setEnable(false)
    })
  }, [])
  return (
    <>
      <Spin enable={enable} overlay/>
      {
        auditMode ?
          <>
            <NavigationBar cancelBack leftNode={<Text className="bold font-36" style={{color:'#323635'}} >文章列表</Text>}  />
            <View className='bg-white rounded-20 clip m-3 px-3'>
              {
                articles.map(d => <ArticlesBox key={d.id} data={d}/>)
              }
            </View>
            <PageScript/>
          </>
          : <Index/>
      }
    </>
  )
}

export default AuditMode
