import {FC, useEffect, useState} from "react";
import {Profile} from "@/store";
import {Image, Radio, Text, View} from "@tarojs/components";
import Taro from "@tarojs/taro";
import styles from './login.module.scss'
import {userApi} from "@/api";
import {loginApi, LoginParams} from "@/api/login";
import MyButton from "@/components/button/MyButton";
import logo from '@/static/img/logo.svg'
import IconFont from "@/components/IconFont";


const Login: FC = () => {
  const [isLoading, setLoading] = useState(false)
  const {setUser, setToken, setCompany, empty} = Profile.useContainer()
  const [h5params, setH5Params] = useState<LoginParams | null>(null)
  const [check, setCheck] = useState(false)

  useEffect(() => {
    empty(false)
    if (process.env.TARO_ENV === 'h5') {
      setLoading(true);
      loginApi.getParams().then((res) => {
        setH5Params(res);
        setError(null);
      }).catch(e => {
        setError(e?.errMsg ?? '系统内部错误')
      }).finally(() => {
        setLoading(false);
      })
    }
  }, [])

  function  setError(msg: any){
    if(msg) {
      Taro.showToast({
        title:msg,
        icon:'none'
      })
    }
  }
  function login() {
    if (isLoading) return;

    if (!check) {
      setError('请阅读并同意《用户协议》及《隐私政策》！')
      return;
    }
    if (h5params == null && process.env.TARO_ENV === 'h5') {
      setError('页面参数错误，请刷新页面！')
      return;
    }

    setLoading(true)

    if (process.env.TARO_ENV === 'h5') {
      location.href = "https://open.weixin.qq.com/connect/oauth2/authorize?" +
        "appid=" + h5params!.appid +
        "&redirect_uri=" + encodeURIComponent(h5params!.route) +
        "&response_type=code" +
        "&scope=snsapi_userinfo" +
        "#wechat_redirect";
    } else {
      Taro.login({
        success: async (res) => {
          try {
            const {catch_key, user, token, company} = await userApi.login(res.code)
            if (token) {
              setUser(user)
              setToken(token)
              setCompany(company)
              setLoading(false)
              setTimeout(() => {
                Taro.navigateBack()
              })
            } else {
              Taro.setStorageSync('openid', catch_key)
              Taro.navigateTo({url: '/pages/check/check'})
            }
          } catch (e) {
          }
          setLoading(false)
        },
        fail: (res) => {
          setError(res.errMsg)
          setLoading(false)
        },
      })
    }
  }

  // async function TESTLOGIN() {
  //   const res = await loginApi.testLogin()
  //   Taro.setStorageSync('profile', JSON.stringify(res))
  //   Taro.reLaunch({url: '/pages/home/home'})
  // }

  return (
    <View className={styles.container}>
      <View className={styles.brand}>
        <Image mode={'scaleToFill'} src={logo}/>
        <View>信桂</View>
      </View>

      <View
        className="p-3 mb-7 flex align-baseline rounded-10 font-30 lh1_5"
        style={{color:'#FF9E5F',backgroundColor:'rgba(255,158,95,0.05)',border:'1px solid rgba(0,0,0,0.03)'}}
      >
        <IconFont className="mr-2" name={'exclamation'} shape={'triangle'} fill></IconFont>
        <View className="flex-1">
          <Text>只有与我司签署了</Text>
          <Text>战略合作</Text>
          <Text>的客户才能够完成登录。</Text>
          <Text onClick={()=>{
            Taro.navigateTo({
              url:`/pages/preview/webView/webView?url=${process.env.TARO_APP_API}/QA/zhanluehezuo.html`
            })
          }} className="text-success" style={{textDecoration:'underline'}}>了解战略合作</Text>
        </View>

      </View>

      {/*<View className={styles.loginTips}>*/}
      {/*  <Text>请完成微信授权以继续使用！</Text>*/}
      {/*</View>*/}
      <MyButton onClick={login} loading={isLoading}>授权登录</MyButton>

      {/*{error ? <View className={styles.errorTips}>*/}
      {/*  <View style={{flex: 1}} className="flex align-baseline">*/}
      {/*    <IconFont className="mr-2" name={'exclamation'} shape={'triangle'} fill></IconFont>*/}
      {/*    <View className='flex-1 ml-1'>{error}</View>*/}
      {/*</View>*/}
      {/*  <View className="p-2" onClick={() => setError(null)}>*/}
      {/*    <Icon name={'close'} />*/}
      {/*  </View>*/}
      {/*</View> : null}*/}
      <View className="mt-2 text-center">
        <Radio style={{transform:'scale(0.8)'}} color={'#45D4A8'} checked={check} onClick={()=> setCheck(!check) }></Radio>
        <Text className="ml-1">阅读并同意</Text>
        <Text className="text-success" onClick={() => {
          Taro.navigateTo({
            url:`/pages/preview/webView/webView?url=${process.env.TARO_APP_API}/yonghuxieyi.html`
          })
        }}>《用户协议》</Text>
        <Text>和</Text>
        <Text className="text-success" onClick={() => {
          Taro.navigateTo({
            url:`/pages/preview/webView/webView?url=${process.env.TARO_APP_API}/yinsizhengce.html`
          })
        }}>《隐私政策》</Text>
      </View>
      {/*{process.env.TARO_APP_LGOIN === 'true' && <MyButton onClick={TESTLOGIN}>线下登录</MyButton>}*/}

      <View className="fixed left right bottom text-center text-muted mb-7 font-26" style={{opacity:'0.5'}}>蜀ICP备20015955号-4X</View>
    </View>
  )
}


export default Login
