import {Button, Form, Input, View} from "@tarojs/components";
import {useEffect, useState} from "react";
import {ManageApi} from "@/api/manage";
import Taro from "@tarojs/taro";
import './addDepartment.scss';
import {getCurrentInstance} from "@tarojs/runtime";

const AddDepartment = () => {
  const [departmentInfo, setDepartmentInfo] = useState<{ name: string } | null>(null)
  const params = getCurrentInstance()?.router?.params as { id?: string;parent_id?: string;sort?: string;company_id?:string }

  useEffect(() => {
    Taro.setNavigationBarTitle({ title:'添加部门'  })
    if (params.id) {
      Taro.setNavigationBarTitle({ title:'修改部门'  })
    }
  }, [])


  async function submit(e) {
    const value: {name: string} = e.detail.value
    for (const [_, val] of Object.entries(value)) {
      if (!val) {
        Taro.showToast({title: "请填写部门名称a", icon: 'error'})
        return
      }
    }
    Taro.showLoading()
    try {
      if (params.id) {
        await ManageApi.putDep(params.id, departmentInfo!.name)
      } else {
        await ManageApi.addDep({
          name: departmentInfo!.name,
          parent_id: Number(params.parent_id),
          company_id: Number(params.company_id),
          sort: Number(params.sort),
        })
      }
      Taro.hideLoading()
      Taro.showToast({title: "添加成功", icon: 'success'})
      setTimeout(() => {
        Taro.navigateBack()
      }, 500)
    } catch (e) {
    }
    Taro.hideLoading()
  }

  function onBlur(e){
    setDepartmentInfo(p => ({...p,name:e.detail.value}))
  }

  return (
    <View className='bg-white px-2 mt-2'>
      <Form className='form' onSubmit={submit}>
        <View className='item'>
          <View>部门</View>
          <Input placeholder='请输入部门名称' name='name' value={departmentInfo?.name}
                 onBlur={onBlur}/>
        </View>
        <Button className='add button' formType='submit'>{params.id ? '修改部门' : "添加部门"}</Button>
      </Form>
    </View>
  )
}

export default AddDepartment
