import {FC, useCallback, useEffect, useState} from "react";
import {Image, Text, View} from "@tarojs/components";
import {Meeting, meetingAPi} from "@/api";
import styles from './meetings.module.scss'
import Taro, {useReachBottom} from "@tarojs/taro";
import Empty from "@/components/empty/empty";
import {formatDate} from "@/utils/time";
import {AtList, AtSwipeAction} from "taro-ui";
import meetingEnd from "@/static/img/meetingEnd.png"
import Spin from "@/components/spinner";

const MeetingsConfig: FC = () => {
  const [page, setPage] = useState(1)
  const [meeting, setMeeting] = useState<Meeting[]>([])
  const [total, setTotal] = useState(0)
  const [curIndex, setCurIndex] = useState<Number>()
  const [enable, setEnable] = useState(true)

  const getData = useCallback(async () => {
    try {
      const res = await meetingAPi.setList(page, 10)
      setTotal(res.total)
      setMeeting([
        ...(meeting || []),
        ...res.data
      ])
    } catch (e) {
    }

    setTimeout(()=>{setEnable(false)},500)
  }, [page])

  function del(id: number, index: number) {
    try {
      Taro.showModal({
        title: `确定删除 ${meeting[index].name}`,
        async success({confirm}) {
          if (confirm) {
            await meetingAPi.del(id)

            const oldMeeting: Meeting[] = JSON.parse(JSON.stringify(meeting))
            oldMeeting.splice(index, 1)
            setMeeting(oldMeeting)
            setCurIndex(undefined)
          }else{
            setCurIndex(undefined)
          }
        }
      })
    } catch (e) {
    }
  }

  useReachBottom(useCallback(() => {
    if (meeting?.length < total) {
      setPage(page + 1)
    }
  }, [total, meeting]))

  useEffect(() => {
    getData()
  }, [page])

  async function handleClick(id : number,index: number){
    await del(id,index)
  }

  function onOpened(index: number){
    setCurIndex(index)
  }

  return (
    <>
    <Spin enable={enable} overlay/>
    <View className='p-2' style={{boxSizing:'border-box',width:'750rpx'}}>

      {
        meeting.length ?
          <AtList>
            {meeting.map((d,index) => (
              <AtSwipeAction
                style={{width:'710rpx'}}
                key={index}
                onClick={()=>{handleClick(d.id,index)}}
                isOpened={curIndex === index}
                onOpened={() => {onOpened(index)}}
                options={[{text: '删除',style: {backgroundColor: '#FF4949'},}]}
              >
                <View className={styles.meeting} key={d.id}>
                  <View className="absolute top bottom right z1 flex  justify-end align-center mr-2">
                    <Image style={{width:'88rpx',height:'88rpx'}}  src={meetingEnd}></Image>
                  </View>
                  <View className="relative z2 flex flex-column">
                    <Text className={styles.title}>{d.name}</Text>
                    <View className={styles.time}>{formatDate(new Date(d.estimate_start_time), "MM-dd")} 至 {formatDate(new Date(d.estimate_start_time), "MM-dd")}</View>
                  </View>
                </View>
              </AtSwipeAction>
            ))}
          </AtList>

          : <Empty name='无历史记录'/>
      }
    </View>
    </>
  )
}

export default MeetingsConfig
