import {FC, useState} from "react";
import {Button, Text, View, WebView} from "@tarojs/components";
import Taro, {useRouter} from "@tarojs/taro";
import IconFont from "@/components/IconFont";

const Web: FC = () => {
  const [hasError, showError] = useState(false)
  const {url} = useRouter().params as unknown as { url: string }

  const onError = () => {
    showError(true)
    Taro.hideNavigationBarLoading()
  }

  const onRefresh = () => {
    showError(false)
    Taro.showNavigationBarLoading()
  }

  Taro.useDidShow(() => {
    Taro.showNavigationBarLoading()
  })

  if (hasError) {
    return (
      <View className='flex flex-column align-center fixed left right top bottom'>
        <View className='flex flex-column justify-end align-center' style={{height:'40%'}}>
          <View className='mb-7'>加载失败</View>
        </View>
        <View className='flex justify-center align-center gap20rpx'>
          <Button className='inlineblock' size='mini' onClick={() => Taro.navigateBack()}>
            <IconFont name='chevron-left' />
            <Text>返回</Text>
          </Button>
          <Button className='inlineblock' size='mini' type='primary' onClick={onRefresh}>
            <IconFont name='arrow-clockwise' />
            <Text>刷新</Text>
          </Button>
        </View>
      </View>
    )
  }

  return (
    <WebView
      progressbarColor='#45D4A8'
      src={decodeURIComponent(url)}
      onLoad={() => Taro.hideNavigationBarLoading()}
      onError={onError}
    />
  )
}

export default Web
